@@ -1,9 +1,10 @@
 import platform
+import pprint
 
 import packaging.version
 import pytest
 
-from dirty_equals import Contains, IsApprox, IsInt, IsNegative, IsOneOf, IsPositive, IsStr
+from dirty_equals import Contains, IsApprox, IsInt, IsList, IsNegative, IsOneOf, IsPositive, IsStr
 from dirty_equals.version import VERSION
 
 
@@ -39,8 +40,7 @@ def test_value_eq():
         v.value
 
     assert 'foo' == v
-    assert str(v) == "'foo'"
-    assert repr(v) == "'foo'"
+    assert repr(v) == str(v) == "'foo'" == pprint.pformat(v)
     assert v.value == 'foo'
 
 
@@ -50,8 +50,7 @@ def test_value_ne():
     with pytest.raises(AssertionError):
         assert 1 == v
 
-    assert str(v) == 'IsStr()'
-    assert repr(v) == 'IsStr()'
+    assert repr(v) == str(v) == 'IsStr()' == pprint.pformat(v)
     with pytest.raises(AttributeError, match='value is not available until __eq__ has been called'):
         v.value
 
@@ -110,7 +109,7 @@ def test_repr():
     ],
 )
 def test_repr_class(v, v_repr):
-    assert repr(v) == v_repr
+    assert repr(v) == str(v) == v_repr == pprint.pformat(v)
 
 
 def test_is_approx_without_init():
@@ -119,11 +118,62 @@ def test_is_approx_without_init():
 
 def test_ne_repr():
     v = IsInt
-    assert repr(v) == 'IsInt'
+    assert repr(v) == str(v) == 'IsInt' == pprint.pformat(v)
 
     assert 'x' != v
 
-    assert repr(v) == 'IsInt'
+    assert repr(v) == str(v) == 'IsInt' == pprint.pformat(v)
+
+
+def test_pprint():
+    v = [IsList(length=...), 1, [IsList(length=...), 2], 3, IsInt()]
+    lorem = ['lorem', 'ipsum', 'dolor', 'sit', 'amet'] * 2
+    with pytest.raises(AssertionError):
+        assert [lorem, 1, [lorem, 2], 3, '4'] == v
+
+    assert repr(v) == (f'[{lorem}, 1, [{lorem}, 2], 3, IsInt()]')
+    assert pprint.pformat(v) == (
+        "[['lorem',\n"
+        "  'ipsum',\n"
+        "  'dolor',\n"
+        "  'sit',\n"
+        "  'amet',\n"
+        "  'lorem',\n"
+        "  'ipsum',\n"
+        "  'dolor',\n"
+        "  'sit',\n"
+        "  'amet'],\n"
+        ' 1,\n'
+        " [['lorem',\n"
+        "   'ipsum',\n"
+        "   'dolor',\n"
+        "   'sit',\n"
+        "   'amet',\n"
+        "   'lorem',\n"
+        "   'ipsum',\n"
+        "   'dolor',\n"
+        "   'sit',\n"
+        "   'amet'],\n"
+        '  2],\n'
+        ' 3,\n'
+        ' IsInt()]'
+    )
+
+
+def test_pprint_not_equal():
+    v = IsList(*range(30))  # need a big value to trigger pprint
+    with pytest.raises(AssertionError):
+        assert [] == v
+
+    assert (
+        pprint.pformat(v)
+        == (
+            'IsList(0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, '
+            '15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29)'
+        )
+        == repr(v)
+        == str(v)
+    )
 
 
 @pytest.mark.parametrize(
